@@ -1,10 +1,11 @@
-# -*- coding: utf-8 -*-
-from __future__ import print_function, unicode_literals
-
+import datetime
 import logging
 import os
 import re
 from collections import OrderedDict
+from html import escape
+from html.parser import HTMLParser
+from io import StringIO
 
 import docutils
 import docutils.core
@@ -12,16 +13,11 @@ import docutils.io
 from docutils.parsers.rst.languages import get_language as get_docutils_lang
 from docutils.writers.html4css1 import HTMLTranslator, Writer
 
-import six
-from six import StringIO
-from six.moves.html_parser import HTMLParser
-
 from pelican import rstdirectives  # NOQA
-from pelican import signals
 from pelican.cache import FileStampDataCacher
 from pelican.contents import Author, Category, Page, Tag
-from pelican.utils import SafeDatetime, escape_html, get_date, pelican_open, \
-    posixize_path
+from pelican.plugins import signals
+from pelican.utils import get_date, pelican_open, posixize_path
 
 try:
     from markdown import Markdown
@@ -79,7 +75,7 @@ def ensure_metadata_list(text):
        Regardless, all list items undergo .strip() before returning, and
        empty items are discarded.
     """
-    if isinstance(text, six.text_type):
+    if isinstance(text, str):
         if ';' in text:
             text = text.split(';')
         else:
@@ -103,7 +99,7 @@ def _filter_discardable_metadata(metadata):
     return {name: val for name, val in metadata.items() if val is not _DISCARD}
 
 
-class BaseReader(object):
+class BaseReader:
     """Base class to read files.
 
     This class is used to process static files, and it can be inherited for
@@ -138,7 +134,7 @@ class BaseReader(object):
 class _FieldBodyTranslator(HTMLTranslator):
 
     def __init__(self, document):
-        HTMLTranslator.__init__(self, document)
+        super().__init__(document)
         self.compact_p = None
 
     def astext(self):
@@ -160,7 +156,7 @@ def render_node_to_html(document, node, field_body_translator_class):
 class PelicanHTMLWriter(Writer):
 
     def __init__(self):
-        Writer.__init__(self)
+        super().__init__()
         self.translator_class = PelicanHTMLTranslator
 
 
@@ -203,21 +199,8 @@ class RstReader(BaseReader):
     writer_class = PelicanHTMLWriter
     field_body_translator_class = _FieldBodyTranslator
 
-    class FileInput(docutils.io.FileInput):
-        """Patch docutils.io.FileInput to remove "U" mode in py3.
-
-        Universal newlines is enabled by default and "U" mode is deprecated
-        in py3.
-
-        """
-
-        def __init__(self, *args, **kwargs):
-            if six.PY3:
-                kwargs['mode'] = kwargs.get('mode', 'r').replace('U', '')
-            docutils.io.FileInput.__init__(self, *args, **kwargs)
-
     def __init__(self, *args, **kwargs):
-        super(RstReader, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         lang_code = self.settings.get('DEFAULT_LANG', 'en')
         if get_docutils_lang(lang_code):
@@ -244,7 +227,7 @@ class RstReader(BaseReader):
                 if element.tagname == 'field':  # custom fields (e.g. summary)
                     name_elem, body_elem = element.children
                     name = name_elem.astext()
-                    if name in formatted_fields:
+                    if name.lower() in formatted_fields:
                         value = render_node_to_html(
                             document, body_elem,
                             self.field_body_translator_class)
@@ -276,7 +259,6 @@ class RstReader(BaseReader):
 
         pub = docutils.core.Publisher(
             writer=self.writer_class(),
-            source_class=self.FileInput,
             destination_class=docutils.io.StringOutput)
         pub.set_components('standalone', 'restructuredtext', 'html')
         pub.process_programmatic_settings(None, extra_params, None)
@@ -303,7 +285,7 @@ class MarkdownReader(BaseReader):
     file_extensions = ['md', 'markdown', 'mkd', 'mdown']
 
     def __init__(self, *args, **kwargs):
-        super(MarkdownReader, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         settings = self.settings['MARKDOWN']
         settings.setdefault('extension_configs', {})
         settings.setdefault('extensions', [])
@@ -318,6 +300,9 @@ class MarkdownReader(BaseReader):
         """Return the dict containing document metadata"""
         formatted_fields = self.settings['FORMATTED_FIELDS']
 
+        # prevent metadata extraction in fields
+        self._md.preprocessors.deregister('meta')
+
         output = {}
         for name, value in meta.items():
             name = name.lower()
@@ -366,11 +351,7 @@ class HTMLReader(BaseReader):
 
     class _HTMLParser(HTMLParser):
         def __init__(self, settings, filename):
-            try:
-                # Python 3.5+
-                HTMLParser.__init__(self, convert_charrefs=False)
-            except TypeError:
-                HTMLParser.__init__(self)
+            super().__init__(convert_charrefs=False)
             self.body = ''
             self.metadata = {}
             self.settings = settings
@@ -415,7 +396,7 @@ class HTMLReader(BaseReader):
                 self._in_body = False
                 self._in_top_level = True
             elif self._in_body:
-                self._data_buffer += '</{}>'.format(escape_html(tag))
+                self._data_buffer += '</{}>'.format(escape(tag))
 
         def handle_startendtag(self, tag, attrs):
             if tag == 'meta' and self._in_head:
@@ -436,16 +417,16 @@ class HTMLReader(BaseReader):
             self._data_buffer += '&#{};'.format(data)
 
         def build_tag(self, tag, attrs, close_tag):
-            result = '<{}'.format(escape_html(tag))
+            result = '<{}'.format(escape(tag))
             for k, v in attrs:
-                result += ' ' + escape_html(k)
+                result += ' ' + escape(k)
                 if v is not None:
                     # If the attribute value contains a double quote, surround
                     # with single quotes, otherwise use double quotes.
                     if '"' in v:
-                        result += "='{}'".format(escape_html(v, quote=False))
+                        result += "='{}'".format(escape(v, quote=False))
                     else:
-                        result += '="{}"'.format(escape_html(v, quote=False))
+                        result += '="{}"'.format(escape(v, quote=False))
             if close_tag:
                 return result + ' />'
             return result + '>'
@@ -543,9 +524,7 @@ class Readers(FileStampDataCacher):
                             self.settings['CONTENT_CACHING_LAYER'] == 'reader')
         caching_policy = cache_this_level and self.settings['CACHE_CONTENT']
         load_policy = cache_this_level and self.settings['LOAD_CONTENT_CACHE']
-        super(Readers, self).__init__(settings, cache_name,
-                                      caching_policy, load_policy,
-                                      )
+        super().__init__(settings, cache_name, caching_policy, load_policy)
 
     @property
     def extensions(self):
@@ -604,6 +583,14 @@ class Readers(FileStampDataCacher):
             from typogrify.filters import typogrify
             import smartypants
 
+            typogrify_dashes = self.settings['TYPOGRIFY_DASHES']
+            if typogrify_dashes == 'oldschool':
+                smartypants.Attr.default = smartypants.Attr.set2
+            elif typogrify_dashes == 'oldschool_inverted':
+                smartypants.Attr.default = smartypants.Attr.set3
+            else:
+                smartypants.Attr.default = smartypants.Attr.set1
+
             # Tell `smartypants` to also replace &quot; HTML entities with
             # smart quotes. This is necessary because Docutils has already
             # replaced double quotes with said entities by the time we run
@@ -685,10 +672,10 @@ def default_metadata(settings=None, process=None):
             metadata['category'] = value
         if settings.get('DEFAULT_DATE', None) and \
            settings['DEFAULT_DATE'] != 'fs':
-            if isinstance(settings['DEFAULT_DATE'], six.string_types):
+            if isinstance(settings['DEFAULT_DATE'], str):
                 metadata['date'] = get_date(settings['DEFAULT_DATE'])
             else:
-                metadata['date'] = SafeDatetime(*settings['DEFAULT_DATE'])
+                metadata['date'] = datetime.datetime(*settings['DEFAULT_DATE'])
     return metadata
 
 
@@ -696,8 +683,9 @@ def path_metadata(full_path, source_path, settings=None):
     metadata = {}
     if settings:
         if settings.get('DEFAULT_DATE', None) == 'fs':
-            metadata['date'] = SafeDatetime.fromtimestamp(
+            metadata['date'] = datetime.datetime.fromtimestamp(
                 os.stat(full_path).st_mtime)
+            metadata['modified'] = metadata['date']
 
         # Apply EXTRA_PATH_METADATA for the source path and the paths of any
         # parent directories. Sorting EPM first ensures that the most specific
@@ -708,7 +696,7 @@ def path_metadata(full_path, source_path, settings=None):
             # Enforce a trailing slash when checking for parent directories.
             # This prevents false positives when one file or directory's name
             # is a prefix of another's.
-            dirpath = os.path.join(path, '')
+            dirpath = posixize_path(os.path.join(path, ''))
             if source_path == path or source_path.startswith(dirpath):
                 metadata.update(meta)
 
@@ -731,7 +719,7 @@ def parse_path_metadata(source_path, settings=None, process=None):
     ...     process=reader.process_metadata)
     >>> pprint.pprint(metadata)  # doctest: +ELLIPSIS
     {'category': <pelican.urlwrappers.Category object at ...>,
-     'date': SafeDatetime(2013, 1, 1, 0, 0),
+     'date': datetime.datetime(2013, 1, 1, 0, 0),
      'slug': 'my-slug'}
     """
     metadata = {}
